/*
** Module   : TableParameter.java
** Abstract : Container for table handle and calling-side APPEND option.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------Description---------------------------------------------
** 001 SVL 20130226  Created initial version.
*/

package com.goldencode.p2j.util;

import com.goldencode.p2j.persist.*;

/**
 * Container for table handle and calling-side APPEND option. Serves two purposes: 1. passes
 * calling-side APPEND option to the called side; 2. implements interchangeability between TABLE
 * and TABLE-HANDLE parameters (In 4GL you can pass TABLE parameter to a procedure that takes
 * TABLE-HANDLE and vice versa).
 */
public class TableParameter
{
   /** Buffer of the wrapped table. */
   private final Temporary table;

   /** Corresponds calling-side APPEND option. */
   private final boolean append;

   /**
    * Create an instance using a buffer.
    *
    * @param table
    *        Buffer of the wrapped table.
    */
   public TableParameter(Temporary table)
   {
      this.table = table;
      this.append = false;
   }

   /**
    * Create an instance using a buffer.
    *
    * @param table
    *        Buffer of the wrapped table.
    * @param append
    *        Determines if APPEND option was specified on the calling side.
    */
   public TableParameter(Temporary table, boolean append)
   {
      this.table = table;
      this.append = append;
   }

   /**
    * Create an instance using a table handle.
    *
    * @param tableHandle
    *        Handle to the wrapped table.
    */
   public TableParameter(handle tableHandle)
   {
      this.table = null; //TODO handle
      this.append = false;
   }

   /**
    * Create an instance using a table handle.
    *
    * @param tableHandle
    *        Handle to the wrapped table.
    * @param append
    *        Determines if APPEND option was specified on the calling side.
    */
   public TableParameter(handle tableHandle, boolean append)
   {
      this.table = null; //TODO handle
      this.append = append;
   }

   /**
    * Get the handle which references the wrapped table.
    *
    * @return  handle to the wrapped table.
    */
   public handle getTableHandle()
   {
      //TODO implement
      return null;
   }

   /**
    * Get the buffer of the wrapped table.
    *
    * @return  buffer of the wrapped table.
    */
   public Temporary getTable()
   {
      return table;
   }

   /**
    * Determines if the APPEND option was specified on the calling side.
    *
    * @return <code>true</code> if the APPEND option was specified on the calling side.
    */
   public boolean isAppend()
   {
      return append;
   }
}
